# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel
from .conference_playback_ended import ConferencePlaybackEnded

__all__ = ["ConferencePlaybackEndedWebhookEvent"]


class ConferencePlaybackEndedWebhookEvent(BaseModel):
    data: Optional[ConferencePlaybackEnded] = None
