# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict
from typing_extensions import TypedDict

__all__ = ["RunCreateParams"]


class RunCreateParams(TypedDict, total=False):
    input: Dict[str, object]

    metadata: Dict[str, object]
